@@ -1,9 +1,9 @@
-from __future__ import absolute_import
-from __future__ import print_function
-
+from __future__ import absolute_import, print_function
 import logging
+
 from .base import Provider as BaseProvider
 
+
 # localzone is an optional dependency of lexicon; do not throw an ImportError if
 # the dependency is unmet.
 try:
@@ -12,13 +12,14 @@ except ImportError:
     pass
 
 
-logger = logging.getLogger(__name__)
+LOGGER = logging.getLogger(__name__)
 
 NAMESERVER_DOMAINS = []
 
 
 def ProviderParser(subparser):
-    subparser.add_argument("--filename", help="specify location of zone master file")
+    subparser.add_argument(
+        "--filename", help="specify location of zone master file")
 
 
 class Provider(BaseProvider):
@@ -50,7 +51,7 @@ class Provider(BaseProvider):
             if z.add_record(name, type, content, ttl=ttl):  # pylint: disable=no-member
                 result = True
 
-        logger.debug("create_record: %s", result)
+        LOGGER.debug("create_record: %s", result)
         return result
 
     def list_records(self, type=None, name=None, content=None):
@@ -84,7 +85,7 @@ class Provider(BaseProvider):
 
             result.append(rdict)
 
-        logger.debug("list_records: %s", result)
+        LOGGER.debug("list_records: %s", result)
         return result
 
     def update_record(self, identifier, type=None, name=None, content=None):
@@ -106,7 +107,7 @@ class Provider(BaseProvider):
                 if z.update_record(identifier, content):  # pylint: disable=no-member
                     result = True
 
-        logger.debug("update_record: %s", result)
+        LOGGER.debug("update_record: %s", result)
         return result
 
     def delete_record(self, identifier=None, type=None, name=None, content=None):
@@ -124,11 +125,11 @@ class Provider(BaseProvider):
                 ids = [record["id"] for record in records]
 
         if len(ids) > 0:
-            logger.debug("delete_records: %s", ids)
+            LOGGER.debug("delete_records: %s", ids)
             with localzone.manage(self.filename, self.origin, autosave=True) as z:
                 for hashid in ids:
                     z.remove_record(hashid)  # pylint: disable=no-member
-                    logger.debug("delete_record: %s", hashid)
+                    LOGGER.debug("delete_record: %s", hashid)
 
         return True
 
